#
# spec file for package libidn
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libidn
%define lname	libidn11
Version:        1.28
Release:        7.5
Summary:        Support for Internationalized Domain Names (IDN)
License:        (GPL-2.0+ or LGPL-3.0+) and GPL-3.0+
Group:          Development/Libraries/C and C++
Url:            http://www.gnu.org/software/libidn/
Source0:        http://ftp.gnu.org/gnu/%{name}/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
Source2:        http://ftp.gnu.org/gnu/%{name}/%{name}-%{version}.tar.gz.sig
Source3:        libidn.keyring
Patch0:         libidn-CVE-2015-2059.patch
Patch1:         libidn-CVE-2015-2059-2.patch
Patch2:         libidn-CVE-2015-8948.patch
Patch3:         libidn-CVE-2016-6261.patch
Patch4:         libidn-CVE-2016-6262.patch
Patch5:         libidn-CVE-2016-6263.patch
#can't be used without build cycles, so just check the signature in validator
#BuildRequires:  gpg-offline
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  help2man
BuildRequires:  libtool
BuildRequires:  makeinfo
BuildRequires:  pkgconfig
Requires(pre):  %install_info_prereq
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
GNU Libidn is an implementation of the Stringprep, Punycode, and IDNA
specifications defined by the IETF Internationalized Domain Names (IDN)
working group. It is used to prepare internationalized strings (such as
domain name labels, usernames, and passwords) in order to increase the
likelihood that string input and string comparison work in ways that
make sense for typical users around the world. The library contains a
generic Stringprep implementation that does Unicode 3.2 NFKC
normalization, mapping and prohibition of characters, and bidirectional
character handling. Profiles for iSCSI, Kerberos 5, Nameprep, SASL, and
XMPP are included. Punycode and ASCII Compatible Encoding (ACE) via
IDNA is supported.

%package tools
Summary:        Command line utility to convert Int. Domain Names
License:        (GPL-2.0+ or LGPL-3.0+) and GPL-3.0+
Group:          Productivity/Networking/DNS/Utilities
# O/P added for 12.3
Obsoletes:      libidn < %version-%release
Provides:       libidn = %version-%release

%description tools
GNU Libidn is an implementation of the Stringprep, Punycode, and IDNA
specifications defined by the IETF Internationalized Domain Names
(IDN) working group. It is used to prepare internationalized strings
(such as domain name labels, usernames, and passwords) in order to
increase the likelihood that string input and string comparison work
in ways that make sense for typical users around the world. The
library contains a generic Stringprep implementation that does
Unicode 3.2 NFKC normalization, mapping and prohibition of
characters, and bidirectional character handling. Profiles for iSCSI,
Kerberos 5, Nameprep, SASL, and XMPP are included. Punycode and ASCII
Compatible Encoding (ACE) via IDNA is supported.

%package -n %lname
Summary:        Support for Internationalized Domain Names (IDN)
License:        (GPL-2.0+ or LGPL-3.0+) and GPL-3.0+
Group:          System/Libraries
# bug437293
%ifarch ppc64
Obsoletes:      libidn-64bit
%endif

%description -n %lname
GNU Libidn is an implementation of the Stringprep, Punycode, and IDNA
specifications defined by the IETF Internationalized Domain Names
(IDN) working group. It is used to prepare internationalized strings
(such as domain name labels, usernames, and passwords) in order to
increase the likelihood that string input and string comparison work
in ways that make sense for typical users around the world. The
library contains a generic Stringprep implementation that does
Unicode 3.2 NFKC normalization, mapping and prohibition of
characters, and bidirectional character handling. Profiles for iSCSI,
Kerberos 5, Nameprep, SASL, and XMPP are included. Punycode and ASCII
Compatible Encoding (ACE) via IDNA is supported.

%package devel
Summary:        Include Files and Libraries mandatory for Development
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       glibc-devel
# bug437293
%ifarch ppc64
Obsoletes:      libidn-devel-64bit
%endif

%description devel
GNU Libidn is an implementation of the Stringprep, Punycode, and IDNA
specifications defined by the IETF Internationalized Domain Names (IDN)
working group. It is used to prepare internationalized strings (such as
domain name labels, usernames, and passwords) in order to increase the
likelihood that string input and string comparison work in ways that
make sense for typical users around the world. The library contains a
generic Stringprep implementation that does Unicode 3.2 NFKC
normalization, mapping and prohibition of characters, and bidirectional
character handling. Profiles for iSCSI, Kerberos 5, Nameprep, SASL, and
XMPP are included. Punycode and ASCII Compatible Encoding (ACE) via
IDNA is supported.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
# renames in git
mv gltests/stdint.in.h gl/stdint.in.h
mv gltests/stdlib.in.h gl/stdlib.in.h
%patch3 -p1
%patch4 -p1
%patch5 -p1

%build
autoreconf -fvi
%configure --with-pic --disable-static --disable-gtk-doc
make %{?_smp_mflags} V=1

%install
%make_install

rm -f %{buildroot}/%{_infodir}/dir
rm -f %{buildroot}%{_libdir}/libidn.la

%find_lang %{name}

%check
%if ! 0%{?qemu_user_space_build}
export SUSE_ASNEEDED=0
make check %{?_smp_mflags} V=1
%endif

%post tools
%install_info --info-dir=%{_infodir} %{_infodir}/libidn.info.gz

%preun tools
%install_info_delete --info-dir=%{_infodir} %{_infodir}/libidn.info.gz

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%files tools -f %{name}.lang
%defattr(-,root,root)
%dir %{_datadir}/emacs
%dir %{_datadir}/emacs/site-lisp
%doc AUTHORS COPYING* ChangeLog FAQ NEWS README THANKS TODO
%{_infodir}/libidn*
%{_bindir}/idn
%{_mandir}/man1/idn.1.*
%{_datadir}/emacs/site-lisp/idna.el
%{_datadir}/emacs/site-lisp/punycode.el

%files -n %lname
%defattr(-,root,root)
%_libdir/libidn.so.11*

%files devel
%defattr(-,root,root)
%{_libdir}/libidn.so
%{_includedir}/*.h
%{_libdir}/pkgconfig/libidn.pc

%changelog
* Fri Jul 22 2016 tchvatal@suse.com
- Add patch for bnc#990189 CVE-2015-8948:
  * libidn-CVE-2015-8948.patch
- Add patch for bnc#990190 CVE-2016-6261:
  * libidn-CVE-2016-6261.patch
- Add patch for bnc#990189 CVE-2016-6262:
  * libidn-CVE-2016-6262.patch
- Add patch for bnc#990191 CVE-2016-6263:
  * libidn-CVE-2016-6263.patch
- Add patch for bnc#923241 CVE-2015-2059:
  * libidn-CVE-2015-2059.patch
  * libidn-CVE-2015-2059-2.patch
- Disable man page generating for the devel mans, it breaks after
  autoreconf
* Thu Dec 19 2013 coolo@suse.com
- disable gpg-offline again to avoid build cycles
* Wed Dec 18 2013 mvyskocil@suse.com
- Verify source tarball via gpg-offline
* Sat Dec 14 2013 uweigand@de.ibm.com
- Fix gnulib test failure due to SUSE_ASNEEDED.
* Mon Sep 23 2013 tchvatal@suse.com
- Version bump to 1.28:
  * java buildfixes
  * translation updates
  * improved unit-tests
  * for more read NEWS file
* Fri Sep 21 2012 jengelh@inai.de
- Employ shared library package naming
* Tue Jun  5 2012 vdziewiecki@suse.com
-Update to 1.25:
  * MSVC: Build fixes related to _GL_ATTRIBUTE_CONST and
    _GL_ATTRIBUTE_PURE.
    Reported by Bartosz Brachaczek <b.brachaczek@gmail.com>.
  * examples: Fix compiler warning about ignoring return value from
    fgets.
  * tests: Ship with a valgrind suppressions file for the strlen
    issue.
  * Update gnulib files and translations.
  * API and ABI is backwards compatible with the previous version.
* Sun May 13 2012 Nico.Laus.2001@gmx.de
- Upgrade to version 1.24
  * Libraries are re-licensed from LGPLv2+ to dual-GPLv2+|LGPLv3+.
  * build: Fix parallel Windows builds.
    Reported by René Berber
  * libidn: Fix potential infloop in pr29 code.
    Reported by Jon Nelson <address@hidden> in
    http://lists.gnu.org/archive/html/help-libidn/2012-01/msg00008.html
  * libidn: Add 'const' keyword to 'stringprep_ucs4_nfkc_normalize' function.
  * Sync glib NFKC code and improve copyright/license statements.
  * Update gnulib files and translations.
  * API and ABI is backwards compatible with the previous version.
* Mon Dec 26 2011 jengelh@medozas.de
- Remove redundant tags/sections
* Mon Dec 26 2011 crrodriguez@opensuse.org
- fix URL
* Mon Dec 26 2011 crrodriguez@opensuse.org
- Update to version 1.23
- Run spec cleaner
* Sat Oct  1 2011 crrodriguez@opensuse.org
- Do not build gtk-docs
- make check hangs in qemu-arm, workaround the bugs.
* Fri Jun 10 2011 andrea.turrini@gmail.com
- Fixed typo in description of libidn.spec
* Sat May  7 2011 crrodriguez@opensuse.org
- Upgrade to version 1.22
  * Fix memory leak when idna_to_ascii_4i fails
  * Fix ToUnicode case-insensitivity bug
  * Avoid some warnings to make it build with modern gcc on amd64.
* Tue Dec 15 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Tue Oct  6 2009 crrodriguez@opensuse.org
- update to version 1.15
  * support GCC visibility features
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Tue Oct 14 2008 crrodriguez@suse.de
- disable static libraries
* Tue Oct  7 2008 stbinner@suse.de
- update to 1.10:
  * idn: accept -n as short form for --nfkc.
  * Fix compiler warnings, updated gnulib files and translations
* Mon Jul 21 2008 stbinner@suse.de
- update to 1.9:
  * idn: fix error message when NFKC fails, and other translations
  * Remove more non-free text from doc/specifications/rfc3454.txt.
* Thu Apr 24 2008 stbinner@suse.de
- update to 1.8: no functional changes
* Mon Apr 14 2008 stbinner@suse.de
- update to 1.7:
  * new parameter --nfkc to process string with Unicode v3.2 NFKC
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Tue Mar 25 2008 stbinner@suse.de
- update to 1.6:
  * Remove non-free portions of doc/specifications/rfc3454.txt.
  * Doc fixes in IDNA to clarify that some functions operate on
    just one domain labels and some operate on domain name (which
    can contain several domain labels).
* Tue Mar 18 2008 crrodriguez@suse.de
- remove "la" file with empty dependency_libs
* Wed Feb 27 2008 stbinner@suse.de
- update to 1.5:
  * Don't include wchar.h in idn-int.h.
  * Added appendix 'On Label Separators' to the manual.
  * Improved rendering of non-ASCII in the info manual.
  * Fix non-portable use of brace expansion in makefiles.
  * Update translations.
* Sun Jan 27 2008 stbinner@suse.de
- update to 1.4: updated translations and fix of --version/--help
* Fri Aug  3 2007 stbinner@suse.de
- update to 1.0:
  * Command-line tools, examples, etc are now licensed under GPLv3
  * The library is still licensed under LGPL v2.1 for compatibility
    reasons (it is included in glibc).
  * Updated gnulib files and translations
* Tue Jul 17 2007 stbinner@suse.de
- update to 0.6.14:
  * Documentation fixes
  * Install images for the manual in $infodir
  * Updated gnulib files
  * Use AM_JAVACFLAGS instead of JAVACFLAGS in java/misc/Makefile.am
* Thu Mar 29 2007 rguenther@suse.de
- add emacs site-lisp directories.
* Wed Mar 14 2007 stbinner@suse.de
- update to 0.6.11:
  * The C# Libidn port was updated.
  * The Java code has been fixed to properly translate any
    non-ASCII dot into ".".
* Thu Oct 19 2006 stbinner@suse.de
- update to 0.6.8:
  * The gnulib directory is separated into two directories.
  * Update gnulib files.
  * Some minor cleanups, like assuming locale.h and setlocale().
  * API and ABI is backwards compatible with the previous version.
* Thu Sep 14 2006 stbinner@suse.de
- update to 0.6.7:
  * Fix build failure of idn-int.h on C99 platforms.
  * The manual includes GPL license, for the command-line tools.
  * The function, variable and concept index is moved to the end
    of the manual.
  * Update of gnulib files and translations
* Wed Aug 23 2006 stbinner@suse.de
- update to 0.6.6
  * Instead of AX_CREATE_STDINT_H, use the stdint gnulib module,
    for idn-int.h.
  * Update gnulib files.
  * Updated translations.
* Thu Aug 17 2006 aj@suse.de
- Remove unneccasary BuildRequires.
* Mon Jul 10 2006 stbinner@suse.de
- update to 0.6.5
  * links the library with an external libintl for gettext
  * updates the doxygen configuration file to version 1.4.7
  * translation of error messages was fixed
  * warnings on 64-bit platforms were fixed
* Mon May 22 2006 stbinner@suse.de
- update to 0.6.3
  * Fix objdir != srcdir builds for the Java documentation.
  * Update of gnulib files.
  * Make it possible to cross-compile to mingw32.
  * Minor changes in how the C# code is built.
* Thu Jan 26 2006 sbrabec@suse.cz
- Added %%install_info_prereq.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Dec  3 2005 coolo@suse.de
- update to 0.6.0
* Wed Aug  3 2005 coolo@suse.de
- move .la file to -devel package
* Fri Jan 21 2005 coolo@suse.de
- update to 0.5.9
* Thu Oct 14 2004 coolo@suse.de
- update to 0.5.8
* Fri Aug  6 2004 coolo@suse.de
- update to 0.5.3 (integrating schwab's patch)
* Thu Aug  5 2004 coolo@suse.de
- update to 0.5.2
* Sat Jul  3 2004 schwab@suse.de
- Fix invalid free.
* Tue Jun  1 2004 coolo@suse.de
- update to 0.4.8
* Thu Mar  4 2004 coolo@suse.de
- fixing file list and requires
* Wed Feb  4 2004 coolo@suse.de
- update to 0.3.7
* Thu Oct 16 2003 coolo@suse.de
- build as user
* Fri Sep 26 2003 coolo@suse.de
- update to 0.3
* Wed Aug 20 2003 coolo@suse.de
- update to 0.2.2
* Wed Jul 23 2003 coolo@suse.de
- update to 0.2.1
* Tue Jun  3 2003 coolo@suse.de
- Initial package
